# Meiki - Minimal Note taking

## Overview
Create a minimal note taking library

### Storage Backends

| Name     | Dependencies | Release |
|----------|--------------|---------|
| File     | -            | 0.1.0   |
